<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

class WDP_Custom_Condition_Area_Size extends \ADP\BaseVersion\Includes\Rule\Conditions\AbstractCondition implements \ADP\BaseVersion\Includes\Rule\Interfaces\Conditions\ValueComparisonCondition {
	const LT = '<';
	const LTE = '<=';
	const MTE = '>=';
	const MT = '>';

	const AVAILABLE_COMP_METHODS = array(
		self::LT,
		self::LTE,
		self::MTE,
		self::MT,
	);

	/**
	 * @var string
	 */
	protected $comparisonMethod;

	/**
	 * @var float
	 */
	protected $comparisonValue;

	public function check( $cart ) {
		if ( ! $this->isValid() ) {
			return false;
		}

		$value = $this->getTotalAreaSize( $cart );

		return $this->compare_values( $value, $this->comparisonValue, $this->comparisonMethod );
	}

	/**
	 * @param \ADP\BaseVersion\Includes\Cart\Structures\Cart $cart
	 *
	 * @return float
	 */
	private function getTotalAreaSize( $cart ) {
		$total = 0;
		foreach ( $cart->getItems() as $item_key => $item ) {
			$productId = $item->getWcItem()->getProduct()->get_id();

			// take AREA from product custom field
			$item_value = floatval( get_post_meta( $productId, 'area', true ) );
			$total      += $item_value * $item->getQty();
		}

		return $total;
	}

	public static function getType() {
		return 'custom_condition_area_size';
	}

	public static function getLabel() {
		return __( 'Area Size(custom)', 'advanced-dynamic-pricing-for-woocommerce' );
	}

	public static function getTemplatePath() {
		return __DIR__ . '/custom-template-area-size.php';
	}

	public static function getGroup() {
		return \ADP\BaseVersion\Includes\Rule\ConditionsLoader::GROUP_CART_ITEMS;
	}

	/**
	 * @param string $comparisonMethod
	 */
	public function setValueComparisonMethod( $comparisonMethod ) {
		if ( in_array( $comparisonMethod, self::AVAILABLE_COMP_METHODS, true ) ) {
			$this->comparisonMethod = $comparisonMethod;
		}
	}

	/**
	 * @param float|integer $comparisonValue
	 */
	public function setComparisonValue( $comparisonValue ) {
		if ( is_numeric( $comparisonValue ) ) {
			$this->comparisonValue = floatval( $comparisonValue );
		}
	}

	/**
	 * @return string
	 */
	public function getValueComparisonMethod() {
		return $this->comparisonMethod;
	}

	/**
	 * @return float
	 */
	public function getComparisonValue() {
		return $this->comparisonValue;
	}

	/**
	 * @return bool
	 */
	public function isValid() {
		return ! is_null( $this->comparisonMethod ) || ! is_null( $this->comparisonValue );
	}
}
